;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'mail '("supercite"))
(custom-add-loads 'supercite-cite '("supercite"))
(custom-add-loads 'supercite '("supercite"))
(custom-add-loads 'supercite-attr '("supercite"))
(custom-add-loads 'supercite-hooks '("supercite"))
(custom-add-loads 'supercite-frames '("supercite"))
(custom-add-loads 'news '("supercite"))

;;; custom-load.el ends here
